@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.25 21:00:00                  #
+# Updated Date: 2024.01.06 04:00:00                  #
 # ================================================== #
 
 from PySide6.QtGui import QAction, Qt
@@ -17,7 +17,7 @@ from pygpt_net.utils import trans
 class Lang:
     def __init__(self, window=None):
         """
-        Language change controller
+        Language switch controller
 
         :param window: Window instance
         """
@@ -44,7 +44,7 @@ class Lang:
         if lang in self.window.ui.menu['lang']:
             self.window.ui.menu['lang'][lang].setChecked(True)
 
-    def toggle(self, id):
+    def toggle(self, id: str):
         """
         Toggle language
 
@@ -63,13 +63,26 @@ class Lang:
         # output: tabs
         self.window.ui.tabs['output'].setTabText(0, trans('output.tab.chat'))
         self.window.ui.tabs['output'].setTabText(1, trans('output.tab.files'))
+        self.window.ui.tabs['output'].setTabText(2, trans('output.tab.calendar'))
+        self.window.ui.tabs['output'].setTabText(3, trans('output.tab.painter'))
 
         # notepads
         num_notepads = self.window.controller.notepad.get_num_notepads()
         if num_notepads > 0:
             for i in range(1, num_notepads + 1):
-                tab = i + 2
+                tab = (self.window.controller.notepad.start_tab_idx - 1) + i
                 self.window.ui.tabs['output'].setTabText(tab, trans('output.tab.notepad') + " " + str(i))
+        self.window.controller.notepad.reload_tab_names()  # <-- reload tab names to restore custom names if present
+
+        # calendar
+        self.window.controller.calendar.update_current_note_label()
+
+        # painter
+        self.window.ui.nodes['painter.btn.brush'].setText(trans('painter.mode.paint'))
+        self.window.ui.nodes['painter.btn.erase'].setText(trans('painter.mode.erase'))
+        self.window.ui.nodes['painter.btn.capture'].setText(trans('painter.btn.capture'))
+        self.window.ui.nodes['painter.btn.camera.capture'].setText(trans('painter.btn.camera.capture'))
+        self.window.ui.nodes['painter.btn.clear'].setText(trans('painter.btn.clear'))
 
         # context
         self.window.ui.nodes['ctx.label'].setText(trans("ctx.list.label"))
@@ -83,10 +96,10 @@ class Lang:
         self.window.ui.nodes['preset.presets.new'].setText(trans('preset.new'))
         self.window.ui.nodes['preset.clear'].setText(trans('preset.clear'))
         self.window.ui.nodes['preset.use'].setText(trans('preset.use'))
-        self.window.ui.nodes['toolbox.preset.ai_name.label'].setText(trans('toolbox.name.ai'))
-        self.window.ui.nodes['toolbox.preset.user_name.label'].setText(trans('toolbox.name.user'))
+        # self.window.ui.nodes['toolbox.preset.ai_name.label'].setText(trans('toolbox.name.ai'))
+        # self.window.ui.nodes['toolbox.preset.user_name.label'].setText(trans('toolbox.name.user'))
         self.window.ui.nodes['toolbox.prompt.label'].setText(trans("toolbox.prompt"))
-        self.window.ui.nodes['temperature.label'].setText(trans("toolbox.temperature.label"))
+        # self.window.ui.nodes['temperature.label'].setText(trans("toolbox.temperature.label"))
 
         # input
         self.window.ui.nodes['input.label'].setText(trans("input.label"))
@@ -119,11 +132,11 @@ class Lang:
         self.window.ui.nodes['assistant.instructions.label'].setText(trans("assistant.instructions"))
         self.window.ui.nodes['assistant.model.label'].setText(trans("assistant.model"))
         self.window.ui.nodes['assistant.description.label'].setText(trans("assistant.description"))
-        self.window.ui.nodes['assistant.functions.label'].setText(trans('assistant.functions.label'))
+        self.window.ui.nodes['assistant.tool.function.label'].setText(trans('assistant.functions.label'))
         self.window.ui.nodes['assistant.id_tip'].setText(trans("assistant.new.id_tip"))
         self.window.ui.nodes['assistant.api.tip'].setText(trans('assistant.api.tip'))
-        self.window.ui.config_option['assistant.tool.retrieval'].box.setText(trans('assistant.tool.retrieval'))
-        self.window.ui.config_option['assistant.tool.code_interpreter'].box.setText(
+        self.window.ui.config['assistant']['tool.retrieval'].box.setText(trans('assistant.tool.retrieval'))
+        self.window.ui.config['assistant']['tool.code_interpreter'].box.setText(
             trans('assistant.tool.code_interpreter'))
         self.window.ui.dialog['editor.assistants'].setWindowTitle(trans('dialog.assistant'))
 
@@ -133,6 +146,7 @@ class Lang:
         self.window.ui.nodes['vision.capture.auto'].setText(trans("vision.capture.auto"))
         self.window.ui.nodes['vision.capture.auto'].setToolTip(trans('vision.capture.auto.tooltip'))
         self.window.ui.nodes['vision.capture.label'].setText(trans('vision.capture.options.title'))
+        self.window.ui.nodes['inline.vision'].setText(trans("inline.vision"))
 
         # capture label
         if not self.window.core.config.get('vision.capture.auto'):
@@ -173,10 +187,10 @@ class Lang:
         self.window.ui.nodes['preset.btn.current'].setText(trans("dialog.preset.btn.current"))
         self.window.ui.nodes['preset.btn.save'].setText(trans("dialog.preset.btn.save"))
         self.window.ui.nodes['cmd.enabled'].setText(trans('cmd.enabled'))
-        self.window.ui.config_option['preset.chat'].box.setText(trans("preset.chat"))
-        self.window.ui.config_option['preset.completion'].box.setText(trans("preset.completion"))
-        self.window.ui.config_option['preset.img'].box.setText(trans("preset.img"))
-        self.window.ui.config_option['img_raw'].setText(trans("img.raw"))
+        self.window.ui.config['preset']['chat'].box.setText(trans("preset.chat"))
+        self.window.ui.config['preset']['completion'].box.setText(trans("preset.completion"))
+        self.window.ui.config['preset']['img'].box.setText(trans("preset.img"))
+        self.window.ui.config['global']['img_raw'].setText(trans("img.raw"))
 
         # dialog: rename
         self.window.ui.dialog['rename'].setWindowTitle(trans("dialog.rename.title"))
@@ -195,15 +209,15 @@ class Lang:
         self.window.ui.dialog['update'].download.setText(trans('update.download'))
         self.window.ui.dialog['update'].setWindowTitle(trans('update.title'))
 
+        # dialog: image / dall-e
+        self.window.ui.dialog['image'].setWindowTitle(trans("dialog.image.title"))
+
         # menu
         self.window.ui.menu['menu.app'].setTitle(trans("menu.file"))
         self.window.ui.menu['app.ctx.new'].setText(trans("menu.file.new"))
         self.window.ui.menu['app.clear_history'].setText(trans("menu.file_clear_history"))
         self.window.ui.menu['app.exit'].setText(trans("menu.file.exit"))
 
-        self.window.ui.menu['menu.plugins'].setTitle(trans("menu.plugins"))
-        self.window.ui.menu['menu.audio'].setTitle(trans("menu.audio"))
-
         self.window.ui.menu['menu.config'].setTitle(trans("menu.config"))
         self.window.ui.menu['config.settings'].setText(trans("menu.config.settings"))
         self.window.ui.menu['config.edit.config'].setText(trans("menu.config.edit.config"))
@@ -212,7 +226,6 @@ class Lang:
         self.window.ui.menu['config.save'].setText(trans("menu.config.save"))
 
         self.window.ui.menu['menu.lang'].setTitle(trans("menu.lang"))
-        self.window.ui.menu['menu.theme'].setTitle(trans("menu.theme"))
 
         # debug menu
         if 'menu.debug' in self.window.ui.menu:
@@ -226,6 +239,9 @@ class Lang:
             self.window.ui.menu['debug.assistants'].setText(trans("menu.debug.assistants"))
             self.window.ui.menu['debug.ui'].setText(trans("menu.debug.ui"))
 
+        self.window.ui.menu['menu.plugins'].setTitle(trans("menu.plugins"))
+        self.window.ui.menu['plugins.settings'].setText(trans("menu.plugins.settings"))
+
         self.window.ui.menu['menu.about'].setTitle(trans("menu.info"))
         self.window.ui.menu['info.about'].setText(trans("menu.info.about"))
         self.window.ui.menu['info.changelog'].setText(trans("menu.info.changelog"))
@@ -236,6 +252,11 @@ class Lang:
         self.window.ui.menu['info.website'].setText(trans("menu.info.website"))
         self.window.ui.menu['info.github'].setText(trans("menu.info.github"))
 
+        self.window.ui.menu['menu.audio'].setTitle(trans("menu.audio"))
+        self.window.ui.menu['audio.output.azure'].setText(trans('menu.audio.output.azure'))
+        self.window.ui.menu['audio.output.tts'].setText(trans('menu.audio.output.tts'))
+        self.window.ui.menu['audio.input.whisper'].setText(trans('menu.audio.input.whisper'))
+
         # start
         self.window.ui.nodes['start.title'].setText(trans('dialog.start.title.text'))
         self.window.ui.nodes['start.settings'].setText(trans('dialog.start.settings.text'))
@@ -250,6 +271,12 @@ class Lang:
         self.window.ui.nodes['attachments_uploaded.btn.clear'].setText(trans('attachments_uploaded.btn.clear'))
         self.window.ui.nodes['attachments_uploaded.sync.tip'].setText(trans('attachments_uploaded.sync.tip'))
 
+        # filesystem / idx
+        self.window.ui.nodes['output_files'].btn_upload.setText(trans('files.local.upload'))
+        self.window.ui.nodes['output_files'].btn_idx.setText(trans('idx.btn.index_all'))
+        self.window.ui.nodes['output_files'].btn_clear.setText(trans('idx.btn.clear'))
+        self.window.ui.nodes['output_files'].path_label.setText(trans('files.local.dir.prefix') + ': ' + self.window.ui.nodes['output_files'].directory)
+
         # tabs
         mode = self.window.core.config.get('mode')
         self.window.controller.attachment.update_tab(mode)
@@ -257,6 +284,7 @@ class Lang:
         self.window.ui.tabs['input'].setTabText(0, trans('input.tab'))
 
         # theme menu
+        self.window.ui.menu['menu.theme'].setTitle(trans("menu.theme"))
         for theme in self.window.ui.menu['theme']:
             name = self.window.controller.theme.trans_theme(theme)
             self.window.ui.menu['theme'][theme].setText(name)
@@ -271,9 +299,10 @@ class Lang:
             print("Error updating plugin locales", e)
             self.window.core.debug.log(e)
 
+        self.window.controller.ctx.common.update_label_by_current()
         self.window.controller.ctx.update(True, False)
         self.window.controller.ui.update()  # update all (toolbox, etc.)
-        self.window.set_status('')  # clear status
+        self.window.ui.status('')  # clear status
 
     def toggle_plugins(self):
         """Toggle plugins locale"""
@@ -311,7 +340,8 @@ class Lang:
             if id in self.window.ui.menu['plugins']:
                 self.window.ui.menu['plugins'][id].setText(name_txt)
 
-            option_ids = plugin.setup().keys()
+            options = plugin.setup()
+            option_ids = options.keys()
             for option_id in option_ids:
                 # prepare element nodes keys
                 label_key = 'plugin.' + id + '.' + option_id + '.label'
@@ -330,12 +360,13 @@ class Lang:
                     self.window.ui.nodes[desc_key].setText(desc_str)
                     self.window.ui.nodes[desc_key].setToolTip(tooltip_str)
 
-                # update widget tooltip
-                if id in self.window.ui.plugin_option and option_id in self.window.ui.plugin_option[id]:
-                    try:
-                        self.window.ui.plugin_option[id][option_id].setTooltip(tooltip_str)
-                    except Exception as e:
-                        pass
+                if options[option_id]['type'] == 'bool':
+                    # update checkbox label
+                    if domain in self.window.ui.config and option_id in self.window.ui.config[domain]:
+                        try:
+                            self.window.ui.config[domain][option_id].box.setText(label_str)
+                        except Exception as e:
+                            pass
 
         # update settings dialog list
         idx = self.window.ui.tabs['plugin.settings'].currentIndex()
@@ -351,11 +382,11 @@ class Lang:
         # update settings options labels
         for id in self.window.controller.settings.editor.options:
             option = self.window.controller.settings.editor.options[id]
-            option_label = 'settings.{}.label'.format(id)
-            trans_key = 'settings.{}'.format(option['label'])
+            option_label = 'settings.{}.label'.format(id)  # TODO: check
+            trans_key = '{}'.format(option['label'])
             if option['type'] == 'bool':
-                if id in self.window.ui.config_option:
-                    self.window.ui.config_option[id].box.setText(trans(trans_key))
+                if id in self.window.ui.config['config']:
+                    self.window.ui.config['config'][id].box.setText(trans(trans_key))
             else:
                 if option_label in self.window.ui.nodes:
                     self.window.ui.nodes[option_label].setText(trans(trans_key))
