@@ -6,9 +6,29 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.25 21:00:00                  #
+# Updated Date: 2024.01.06 23:00:00                  #
 # ================================================== #
 
+import json
+
+from pygpt_net.item.ctx import CtxItem
+
+
+class Event:
+    def __init__(self, name: str = None, data: dict = None):
+        """
+        Event object class
+
+        :param name: event name
+        :param data: event data
+        """
+        self.name = name
+        self.data = data
+        self.ctx = None
+        self.stop = False
+        self.internal = False  # internal event, not from user, handled synchronously, ctxitem has internal flag
+
+
 class Dispatcher:
     def __init__(self, window=None):
         """
@@ -18,27 +38,32 @@ class Dispatcher:
         """
         self.window = window
 
-    def dispatch(self, event, all=False, is_async=False):
+    def dispatch(self, event: Event, all: bool = False, is_async: bool = False) -> (list, Event):
         """
         Dispatch event to plugins
 
         :param event: event to dispatch
         :param all: true if dispatch to all plugins (enabled or not)
-        :param is_async: true if async event
+        :param is_async: true if async event  TODO: remove this param
+        :return: list of affected plugins ids and event object
         """
+        affected = []
         for id in self.window.core.plugins.plugins:
             if self.window.controller.plugins.is_enabled(id) or all:
                 if event.stop:
                     break
                 self.apply(id, event, is_async)
+                affected.append(id)
 
-    def apply(self, id, event, is_async=False):
+        return affected, event
+
+    def apply(self, id: str, event: Event, is_async: bool = False):
         """
         Handle event in plugin with provided id
 
         :param id: plugin id
         :param event: event object
-        :param is_async: true if async event
+        :param is_async: true if async event  TODO: remove this param
         """
         if id in self.window.core.plugins.plugins:
             try:
@@ -47,16 +72,15 @@ class Dispatcher:
             except AttributeError:
                 pass
 
-
-class Event:
-    def __init__(self, name=None, data=None):
+    def reply(self, ctx: CtxItem):
         """
-        Event class
+        Reply to late response (async event)
 
-        :param name: event name
-        :param data: event data
+        :param ctx: context object
         """
-        self.name = name
-        self.data = data
-        self.ctx = None
-        self.stop = False
+        if ctx is not None:
+            self.window.ui.status("")  # Clear status
+            if ctx.reply:
+                self.window.core.ctx.update_item(ctx)  # update context in db
+                self.window.ui.status('...')
+                self.window.controller.chat.input.send(json.dumps(ctx.results), force=True, internal=ctx.internal)
