@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.25 21:00:00                  #
+# Updated Date: 2023.12.31 04:00:00                  #
 # ================================================== #
 
 from langchain.llms import HuggingFaceTextGenInference
@@ -17,7 +17,7 @@ class Llama2LLM:
     def __init__(self):
         self.id = "llama2"
 
-    def completion(self, config, options, stream=False):
+    def completion(self, config, options: dict, stream: bool = False):
         """
         Return LLM model for completion
 
@@ -28,7 +28,7 @@ class Llama2LLM:
         """
         return None
 
-    def chat(self, config, options, stream=False):
+    def chat(self, config, options: dict, stream: bool = False):
         """
         Return LLM model for chat
 
