@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.25 21:00:00                  #
+# Updated Date: 2023.12.31 04:00:00                  #
 # ================================================== #
 
 from langchain.chat_models import ChatOllama
@@ -16,7 +16,7 @@ class OllamaLLM:
     def __init__(self):
         self.id = "ollama"
 
-    def completion(self, config, options, stream=False):
+    def completion(self, config, options: dict, stream: bool = False):
         """
         Return LLM model for completion
 
@@ -27,7 +27,7 @@ class OllamaLLM:
         """
         return None
 
-    def chat(self, config, options, stream=False):
+    def chat(self, config, options: dict, stream: bool = False):
         """
         Return LLM model for chat
 
