@@ -6,9 +6,13 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2023.12.25 21:00:00                  #
+# Updated Date: 2023.12.31 04:00:00                  #
 # ================================================== #
 
+from packaging.version import Version
+
+from pygpt_net.item.model import ModelItem
+
 
 class BaseProvider:
     def __init__(self, window=None):
@@ -22,26 +26,26 @@ class BaseProvider:
     def install(self):
         pass
 
-    def patch(self, version):
+    def patch(self, version: Version) -> bool:
         pass
 
-    def create(self, meta):
+    def create(self, model: ModelItem) -> str:
         pass
 
-    def load(self):
+    def load(self) -> dict:
         pass
 
-    def save(self, items):
+    def save(self, items: dict):
         pass
 
-    def remove(self, id):
+    def remove(self, id: str):
         pass
 
     def truncate(self):
         pass
 
-    def dump(self, ctx):
+    def dump(self, model: ModelItem):
         pass
 
-    def get_version(self):
+    def get_version(self) -> str:
         pass
